@@ -1,3 +1,6 @@
+#define defgMouseWinMove                XK_1, kfAlt+kfCtrl, "Alt+Ctrl+Pointer_Button1"
+#define defgMouseWinSize                XK_3, kfAlt+kfCtrl, "Alt+Ctrl+Pointer_Button3"
+
 #define defgKeyWinRaise                 XK_F1, kfAlt, "Alt+F1"
 #define defgKeyWinOccupyAll             XK_F2, kfAlt, "Alt+F2"
 #define defgKeyWinLower                 XK_F3, kfAlt, "Alt+F3"
@@ -83,7 +86,7 @@
 #define defgKeySysMinimizeAll           XK_F9, kfAlt+kfShift, "Alt+Shift+F9"
 #define defgKeySysHideAll               XK_F11, kfAlt+kfShift, "Alt+Shift+F11"
 #define defgKeySysUndoArrange           XK_F7, kfAlt+kfShift, "Alt+Shift+F7"
-#define defgKeySysShowDesktop			'd', kfAlt+kfCtrl, "Alt+Ctrl+d"
+#define defgKeySysShowDesktop           'd', kfAlt+kfCtrl, "Alt+Ctrl+d"
 
 #ifdef NO_KEYBIND
 
@@ -110,6 +113,9 @@
 #define KEY_NAME(k) (k.name ? k.name : "")
 #endif
 
+DEF_WMKEY(gMouseWinMove);
+DEF_WMKEY(gMouseWinSize);
+
 DEF_WMKEY(gKeyWinRaise);
 DEF_WMKEY(gKeyWinOccupyAll);
 DEF_WMKEY(gKeyWinLower);
