@@ -211,12 +211,12 @@ void ObjectListBox::activateItem(YListItem *item) {
 
     if (obj->isFolder()) {
         //if (fork() == 0)
-        //    execl("./icelist", "icelist", path, 0);
+        //    execl("./icelist", "icelist", path, NULL);
         ObjectList *list = new ObjectList(path, 0);
         list->show();
     } else {
         if (fork() == 0)
-            execl("./iceview", "iceview", path, 0);
+            execl("./iceview", "iceview", path, NULL);
     }
     delete path;
 }
@@ -263,12 +263,12 @@ public:
 
     virtual void configure(const YRect &r, const bool resized) {
         YWindow::configure(r, resized);
-	if (resized) {
-	    for (int i = 0; i < NPANES; i++)
-		panes[i]->setSize(r.width(), panes[i]->height());
+        if (resized) {
+            for (int i = 0; i < NPANES; i++)
+                panes[i]->setSize(r.width(), panes[i]->height());
             panes[NPANES - 1]->setSize(r.width(),
                                        r.height() - panes[NPANES - 1]->y());
-	}
+        }
     }
 
     void movePane(Pane *pane, int delta);
