@@ -234,69 +234,41 @@ void YFrameClient::constrainSize(int &w, int &h, int flags)
             // !!! fix handling of KeepX and KeepY together
             if (xMin * h > yMin * w) { // min aspect
                 if (flags & csKeepX) {
-		    w = clamp(w, wMin, wMax);
+                    w = clamp(w, wMin, wMax);
                     h = w * yMin / xMin;
-		    h = clamp(h, hMin, hMax);
+                    h = clamp(h, hMin, hMax);
                     w = h * xMin / yMin;
                 } else {
-		    h = clamp(h, hMin, hMax);
+                    h = clamp(h, hMin, hMax);
                     w = h * xMin / yMin;
-		    w = clamp(w, wMin, wMax);
+                    w = clamp(w, wMin, wMax);
                     h = w * yMin / xMin;
                 }
             }
             if (xMax * h < yMax * w) { // max aspect
                 if (flags & csKeepX) {
-		    w = clamp(w, wMin, wMax);
+                    w = clamp(w, wMin, wMax);
                     h = w * yMax / xMax;
-		    h = clamp(h, hMin, hMax);
+                    h = clamp(h, hMin, hMax);
                     w = h * xMax / yMax;
                 } else {
-		    h = clamp(h, hMin, hMax);
+                    h = clamp(h, hMin, hMax);
                     w = h * xMax / yMax;
-		    w = clamp(w, wMin, wMax);
+                    w = clamp(w, wMin, wMax);
                     h = w * yMax / xMax;
                 }
             }
         }
 
-	h = clamp(h, hMin, hMax);
-	w = clamp(w, wMin, wMax);
+        h = clamp(h, hMin, hMax);
+        w = clamp(w, wMin, wMax);
 
-        if (limitSize) {
-#warning "bogus, probably"
-#if 0
-            int Mw, Mh;
-            manager->getWorkAreaSize(getFrame(), &Mw, &Mh);
-#endif
-
-#warning "recheck this code"
-#if 0
-            w = min(w,
-                    (int)((considerHorizBorder && !getFrame()->doNotCover())
-                          ? Mw - 2 * getFrame()->borderX() :
-                          Mw));
-            h = min(h,
-                    (int)((considerVertBorder && !getFrame()->doNotCover())
-                          ? Mh - getFrame()->titleY() - 2 * getFrame()->borderY()
-                          : Mh - getFrame()->titleY()));
-#endif
-        }
-
-#if 0
-        w = wBase + (w - wBase + ((flags & csRound) ? wInc / 2 : 0)) / wInc
-								     * wInc;
-        h = hBase + (h - hBase + ((flags & csRound) ? hInc / 2 : 0)) / hInc
-								     * hInc;
-#else
         if (flags & csRound) {
             w += wInc / 2; h += hInc / 2;
         }
 
-	w-= max(0, w - wBase) % wInc;
-	h-= max(0, h - hBase) % hInc;
-#endif
-
+        w-= max(0, w - wBase) % wInc;
+        h-= max(0, h - hBase) % hInc;
     }
 
     if (w <= 0) w = 1;
@@ -387,6 +359,8 @@ void YFrameClient::setFrameState(FrameState state) {
     if (state == WithdrawnState) {
         if (manager->wmState() != YWindowManager::wmSHUTDOWN) {
             MSG(("deleting window properties id=%lX", handle()));
+            XDeleteProperty(xapp->display(), handle(), _XA_NET_WM_DESKTOP);
+            XDeleteProperty(xapp->display(), handle(), _XA_NET_WM_STATE);
             XDeleteProperty(xapp->display(), handle(), _XA_WIN_WORKSPACE);
             XDeleteProperty(xapp->display(), handle(), _XA_WIN_LAYER);
 #ifdef CONFIG_TRAY
@@ -432,11 +406,11 @@ void YFrameClient::handleUnmap(const XUnmapEvent &unmap) {
 
         XEvent ev;
         if (XCheckTypedWindowEvent(xapp->display(), unmap.window,
-				   DestroyNotify, &ev)) {
+                                   DestroyNotify, &ev)) {
             manager->destroyedClient(unmap.window);
             return; // gets destroyed
         } else if (XCheckTypedWindowEvent(xapp->display(), unmap.window,
-					  ReparentNotify, &ev)) {
+                                          ReparentNotify, &ev)) {
             manager->unmanageClient(unmap.window, true, false);
             return; // gets destroyed
         } else {
@@ -519,7 +493,7 @@ void YFrameClient::handleProperty(const XPropertyEvent &property) {
 #endif
 #ifdef WMSPEC_HINTS
         } else if (property.atom == _XA_NET_WM_STRUT) {
-            msg("change: net wm strut");
+            MSG(("change: net wm strut"));
             if (new_prop) prop.net_wm_strut = true;
             if (getFrame())
                 getFrame()->updateNetWMStrut();
@@ -566,10 +540,10 @@ void YFrameClient::handleProperty(const XPropertyEvent &property) {
             // !!! do we do dynamic update? (discuss on wm-spec)
             prop.net_wm_window_type = new_prop;
 #endif
-	    } else
-		MSG(("Unknown property changed: %s, window=0x%lX",
-		     XGetAtomName(xapp->display(), property.atom), handle()));
-
+        } else {
+            MSG(("Unknown property changed: %s, window=0x%lX",
+                 XGetAtomName(xapp->display(), property.atom), handle()));
+        }
         break;
     }
 }
@@ -729,8 +703,6 @@ void YFrameClient::handleClientMessage(const XClientMessageEvent &message) {
             getMask(message.data.l[2]);
 
         //printf("new state, mask = %ld\n", mask);
-#warning "implement fullscreen state toggle"
-
         if (message.data.l[0] == _NET_WM_STATE_ADD) {
             //puts("add");
             if (getFrame())
