@@ -8,7 +8,6 @@
 #include "wmmgr.h"
 
 #include "aaddressbar.h"
-#include "atasks.h"
 #include "atray.h"
 #include "aworkspaces.h"
 #include "sysdep.h"
@@ -34,12 +33,6 @@ XContext clientContext;
 
 YAction *layerActionSet[WinLayerCount];
 
-#ifdef CONFIG_TRAY
-#if 0
-YAction *trayOptionActionSet[WinTrayOptionCount];
-#endif
-#endif
-
 YWindowManager::YWindowManager(YWindow *parent, Window win):
     YDesktop(parent, win)
 {
@@ -54,12 +47,6 @@ YWindowManager::YWindowManager(YWindow *parent, Window win):
     }
     fFirst = fLast = 0;
     fFirstFocus = fLastFocus = 0;
-#ifdef CONFIG_TRAY
-#if 0
-    for (int k(0); k < WinTrayOptionCount; k++)
-        trayOptionActionSet[k] = new YAction();
-#endif
-#endif
     fColormapWindow = 0;
     fActiveWorkspace = WinWorkspaceInvalid;
     fLastWorkspace = WinWorkspaceInvalid;
@@ -201,27 +188,17 @@ void YWindowManager::grabKeys() {
     }
 #endif
     if (xapp->WinMask && win95keys) {
-        ///  !!! fix -- allow apps to use remaining key combos (except single press)
         if (xapp->Win_L) {
-#if 0
-            grabKey(xapp->Win_L, 0);
-#else
-
             KeyCode keycode = XKeysymToKeycode(xapp->display(), xapp->Win_L);
             if (keycode != 0)
-                XGrabKey(xapp->display(), keycode, 0, desktop->handle(), False,
+                XGrabKey(xapp->display(), keycode, AnyModifier, desktop->handle(), False,
                          GrabModeAsync, GrabModeSync);
-#endif
         }
         if (xapp->Win_R) {
-#if 0
-            grabKey(xapp->Win_R, 0);
-#else
             KeyCode keycode = XKeysymToKeycode(xapp->display(), xapp->Win_R);
             if (keycode != 0)
-                XGrabKey(xapp->display(), keycode, 0, desktop->handle(), False,
+                XGrabKey(xapp->display(), keycode, AnyModifier, desktop->handle(), False,
                          GrabModeAsync, GrabModeSync);
-#endif
         }
     }
 
@@ -479,7 +456,7 @@ bool YWindowManager::handleWMKey(const XKeyEvent &key, KeySym k, unsigned int /*
     } else if(IS_WMKEY(k, vm, gKeySysShowDesktop)) {
         XAllowEvents(xapp->display(), AsyncKeyboard, key.time);
         wmapp->actionPerformed(actionShowDesktop, 0);
-        return true;				
+        return true;                            
     } else {
 #ifndef NO_CONFIGURE_MENUS
         KProgram *p = keyProgs;
@@ -577,15 +554,6 @@ void YWindowManager::handleButton(const XButtonEvent &button) {
             popupWindowListMenu(this, button.x, button.y);
             break;
         }
-#endif
-#if 0
-#ifdef CONFIG_WINLIST
-        if (button.button + 10 == rootWinListButton) {
-            if (windowList)
-                windowList->showFocused(button.x_root, button.y_root);
-            break;
-        }
-#endif
 #endif
     } while (0);
     YWindow::handleButton(button);
@@ -719,10 +687,10 @@ Window YWindowManager::findWindow(const char *resource) {
     char const * dot(resource ? strchr(resource, '.') : 0);
 
     if (dot) {
-	wmInstance = (dot != resource ? newstr(resource, dot - resource) : 0);
-	wmClass = newstr(dot + 1);
+        wmInstance = (dot != resource ? newstr(resource, dot - resource) : 0);
+        wmClass = newstr(dot + 1);
     } else if (resource)
-	wmInstance = newstr(resource);
+        wmInstance = newstr(resource);
 
     Window win = findWindow(desktop->handle(), wmInstance, wmClass);
 
@@ -733,7 +701,7 @@ Window YWindowManager::findWindow(const char *resource) {
 }
 
 Window YWindowManager::findWindow(Window root, char const * wmInstance,
-				  char const * wmClass) {
+                                  char const * wmClass) {
     Window firstMatch = None;
     Window parent, *clients;
     unsigned nClients;
@@ -741,26 +709,26 @@ Window YWindowManager::findWindow(Window root, char const * wmInstance,
     XQueryTree(xapp->display(), root, &root, &parent, &clients, &nClients);
 
     if (clients) {
-	unsigned n;
+        unsigned n;
 
-	for (n = 0; !firstMatch && n < nClients; ++n) {
-	    XClassHint wmclass;
+        for (n = 0; !firstMatch && n < nClients; ++n) {
+            XClassHint wmclass;
 
-	    if (XGetClassHint(xapp->display(), clients[n], &wmclass)) {
-		if ((wmInstance == NULL ||
-		    strcmp(wmInstance, wmclass.res_name) == 0) &&
-		    (wmClass == NULL ||
-		    strcmp(wmClass, wmclass.res_class) == 0))
-		    firstMatch = clients[n];
+            if (XGetClassHint(xapp->display(), clients[n], &wmclass)) {
+                if ((wmInstance == NULL ||
+                    strcmp(wmInstance, wmclass.res_name) == 0) &&
+                    (wmClass == NULL ||
+                    strcmp(wmClass, wmclass.res_class) == 0))
+                    firstMatch = clients[n];
 
-		XFree(wmclass.res_name);
-		XFree(wmclass.res_class);
-	    }
+                XFree(wmclass.res_name);
+                XFree(wmclass.res_class);
+            }
 
-	    if (!firstMatch)
-		firstMatch = findWindow(clients[n], wmInstance, wmClass);
-	}
-	XFree(clients);
+            if (!firstMatch)
+                firstMatch = findWindow(clients[n], wmInstance, wmClass);
+        }
+        XFree(clients);
     }
     return firstMatch;
 }
@@ -790,6 +758,8 @@ void YWindowManager::setFocus(YFrameWindow *f, bool canWarp) {
 #else
 void YWindowManager::setFocus(YFrameWindow *f, bool /*canWarp*/) {
 #endif
+//    updateFullscreenLayerEnable(false);
+
     YFrameClient *c = f ? f->client() : 0;
     Window w = None;
 
@@ -870,58 +840,8 @@ void YWindowManager::setFocus(YFrameWindow *f, bool /*canWarp*/) {
     updateFullscreenLayer();
 }
 
-#if 0
 void YWindowManager::loseFocus(YFrameWindow *window) {
     PRECONDITION(window != 0);
-#ifdef DEBUG
-    if (debug_z) dumpZorder("losing focus: ", window);
-#endif
-    YFrameWindow *w = window->findWindow(YFrameWindow::fwfNext |
-                                         YFrameWindow::fwfVisible |
-                                         YFrameWindow::fwfCycle |
-                                         YFrameWindow::fwfFocusable |
-                                         YFrameWindow::fwfLayers |
-                                         YFrameWindow::fwfWorkspace);
-
-    PRECONDITION(w != window);
-    setFocus(w, false);
-}
-#endif
-
-void YWindowManager::loseFocus(YFrameWindow *window
-#if 0
-                               YFrameWindow *next,
-                               YFrameWindow *prev
-#endif
-                               )
-{
-    PRECONDITION(window != 0);
-#if 0
-#ifdef DEBUG
-    if (debug_z) dumpZorder("close: losing focus: ", window);
-#endif
-
-    YFrameWindow *w = 0;
-
-    if (next)
-        w = next->findWindow(YFrameWindow::fwfVisible |
-                             YFrameWindow::fwfCycle |
-                             YFrameWindow::fwfFocusable |
-                             YFrameWindow::fwfLayers |
-                             YFrameWindow::fwfWorkspace);
-    else if (prev)
-        w = prev->findWindow(YFrameWindow::fwfNext |
-                             YFrameWindow::fwfVisible |
-                             YFrameWindow::fwfCycle |
-                             YFrameWindow::fwfFocusable |
-                             YFrameWindow::fwfLayers |
-                             YFrameWindow::fwfWorkspace);
-
-    if (w == window)
-        w = 0;
-    //msg("loseFocus to %s", w ? w->getTitle() : "<none>");
-    setFocus(w, false);
-#endif
     focusLastWindow();
 }
 
@@ -1178,7 +1098,7 @@ void YWindowManager::smartPlace(YFrameWindow **w, int count) {
             if (s != f->getScreen())
                 continue;
             if (getSmartPlace(false, f, x, y, f->width(), f->height(), s)) {
-                f->setPosition(x, y);
+                f->setNormalPositionOuter(x, y);
             }
         }
     }
@@ -1224,7 +1144,7 @@ void YWindowManager::cascadePlace(YFrameWindow **w, int count) {
         int y;
 
         getCascadePlace(f, lx, ly, x, y, f->width(), f->height());
-        f->setPosition(x, y);
+        f->setNormalPositionOuter(x, y);
     }
 }
 
@@ -1234,8 +1154,8 @@ void YWindowManager::setWindows(YFrameWindow **w, int count, YAction *action) {
     if (count == 0)
         return;
 
-    for (int i = count; i > 0; i--) {
-        YFrameWindow *f = w[i - 1];
+    for (int i = 0; i < count; ++i) {
+        YFrameWindow *f = w[i];
         if (action == actionHideAll) {
             if (!f->isHidden())
                 f->wmHide();
@@ -1261,8 +1181,10 @@ void YWindowManager::getNewPosition(YFrameWindow *frame, int &x, int &y, int w,
     }
 }
 
-void YWindowManager::placeWindow(YFrameWindow *frame, int x, int y,
-				 bool newClient, bool &
+void YWindowManager::placeWindow(YFrameWindow *frame,
+                                 int x, int y,
+                                 int cw, int ch,
+                                 bool newClient, bool &
 #ifdef CONFIG_SESSION
                                  canActivate
 #endif
@@ -1270,10 +1192,10 @@ void YWindowManager::placeWindow(YFrameWindow *frame, int x, int y,
 {
     YFrameClient *client = frame->client();
 
-    int frameWidth = 2 * frame->borderX();
-    int frameHeight = 2 * frame->borderY() + frame->titleY();
-    int posWidth = client->width() + frameWidth;
-    int posHeight = client->height() + frameHeight;
+    int frameWidth = 2 * frame->borderXN();
+    int frameHeight = 2 * frame->borderYN() + frame->titleYN();
+    int posWidth = cw + frameWidth;
+    int posHeight = ch + frameHeight;
     int posX = x;
     int posY = y;
 
@@ -1340,31 +1262,33 @@ void YWindowManager::placeWindow(YFrameWindow *frame, int x, int y,
             (client->sizeHints()->flags & PWinGravity) &&
             client->sizeHints()->win_gravity == StaticGravity)
         {
-            posX -= frame->borderX();
-            posY -= frame->borderY() + frame->titleY();
+            posX -= frame->borderXN();
+            posY -= frame->borderYN() + frame->titleYN();
         } else {
             int gx, gy;
 
             client->gravityOffsets(gx, gy);
 
             if (gx > 0)
-                posX -= 2 * frame->borderX() - 1 - client->getBorder();
+                posX -= 2 * frame->borderXN() - 1 - client->getBorder();
             if (gy > 0)
-                posY -= 2 * frame->borderY() + frame->titleY() - 1 - client->getBorder();
+                posY -= 2 * frame->borderYN() + frame->titleYN() - 1 - client->getBorder();
         }
     }
 
 setGeo:
-    MSG(("mapping geometry (%d:%d %dx%d)", posX, posY, posWidth, posHeight));
-    frame->setNormalGeometry(posX, posY, posWidth, posHeight);
+    MSG(("mapping geometry 1 (%d:%d %dx%d)", posX, posY, posWidth, posHeight));
+    frame->setNormalGeometryOuter(posX, posY, posWidth, posHeight);
 
 }
 
 YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
     YFrameWindow *frame(NULL);
     YFrameClient *client(NULL);
-    int cx(0);
-    int cy(0);
+    int cx = 0;
+    int cy = 0;
+    int cw = 1;
+    int ch = 1;
     bool canManualPlace = false;
     bool canActivate = true;
 
@@ -1418,11 +1342,13 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
         client->setColormap(attributes.colormap);
     }
 
-    MSG(("initial geometry (%d:%d %dx%d)",
+    MSG(("initial geometry 1 (%d:%d %dx%d)",
          client->x(), client->y(), client->width(), client->height()));
 
     cx = client->x();
     cy = client->y();
+    cw = client->width();
+    ch = client->height();
 
     if (client->visible() && wmState() == wmSTARTUP)
         mapClient = true;
@@ -1434,19 +1360,25 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
         delete client;
         goto end;
     }
+    MSG(("initial geometry 2 (%d:%d %dx%d)",
+         client->x(), client->y(), client->width(), client->height()));
 
     frame->doManage(client);
+    MSG(("initial geometry 3 (%d:%d %dx%d)",
+         client->x(), client->y(), client->width(), client->height()));
 
-    placeWindow(frame, cx, cy, (wmState() != wmSTARTUP), canActivate);
+    placeWindow(frame, cx, cy, cw, ch, (wmState() != wmSTARTUP), canActivate);
 
     if ((limitSize || limitPosition) &&
         (wmState() != wmSTARTUP) &&
         !frame->affectsWorkArea())
     {
-        int posX(frame->x() + frame->borderX()),
-	    posY(frame->y() + frame->borderY()),
-	    posWidth(frame->width() - 2 * frame->borderX()),
-	    posHeight(frame->height() - 2 * frame->borderY());
+        int posX(frame->x() + frame->borderXN()),
+            posY(frame->y() + frame->borderYN()),
+            posWidth(frame->width() - 2 * frame->borderXN()),
+            posHeight(frame->height() - 2 * frame->borderYN());
+
+        MSG(("mapping geometry 2 (%d:%d %dx%d)", posX, posY, posWidth, posHeight));
 
         if (limitSize) {
             int Mw, Mh;
@@ -1456,11 +1388,9 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
             posHeight = min(posHeight, Mh);
 
 #warning "cleanup the constrainSize code, there is some duplication"
-            posHeight -= frame->titleY();
-            frame->client()->constrainSize(posWidth, posHeight,
-                                           ///frame->getLayer(),
-                                           0);
-            posHeight += frame->titleY();
+            posHeight -= frame->titleYN();
+            frame->client()->constrainSize(posWidth, posHeight, 0);
+            posHeight += frame->titleYN();
         }
 
         if (limitPosition &&
@@ -1473,12 +1403,10 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
             posX = clamp(posX, mx, Mx - posWidth);
             posY = clamp(posY, my, My - posHeight);
         }
+        posHeight -= frame->titleYN();
 
-        posX -= frame->borderX();
-        posY -= frame->borderY();
-        posWidth += 2 * frame->borderX();
-        posHeight += 2 * frame->borderY();
-        frame->setNormalGeometry(posX, posY, posWidth, posHeight);
+        MSG(("mapping geometry 3 (%d:%d %dx%d)", posX, posY, posWidth, posHeight));
+        frame->setNormalGeometryInner(posX, posY, posWidth, posHeight);
     }
 
     if (!mapClient) {
@@ -1511,10 +1439,8 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
 #ifdef CONFIG_TASKBAR
     frame->updateTaskBar();
 #endif
-    frame->updateNormalSize();
-    frame->updateLayout();
     if (frame->affectsWorkArea())
-	updateWorkArea();
+        updateWorkArea();
     if (mapClient) {
         if (!(frame->getState() & (WinStateHidden | WinStateMinimized)))
         {
@@ -1557,7 +1483,7 @@ YFrameWindow *YWindowManager::mapClient(Window win) {
 }
 
 void YWindowManager::unmanageClient(Window win, bool mapClient,
-				    bool reparent) {
+                                    bool reparent) {
     YFrameWindow *frame = findFrame(win);
 
     MSG(("unmanaging window 0x%lX", win));
@@ -1632,26 +1558,13 @@ YFrameWindow *YWindowManager::getLastFocus(long workspace) {
         {
             if ((w->client() && !w->client()->adopted()))
                 continue;
-//            if (!w->visibleOn(workspace))
-//                continue;
             if (w->isMinimized())
                 continue;
             if (w->isHidden())
                 continue;
-//            msg("--- %d %ld %d  frame %s",
-//                w->isSticky() ? 1 : 0, w->getWorkspace(), w->isFocused() ? 1 : 0, w->getTitle());
             if (!w->isFocusable(true)) {
-//                if (pass == 1) {
-//                    toFocus = w;
-//                    goto gotit;
-//                }
-//            } else if (w->focused()) {
-//                if (pass == 0) {
-//                    toFocus = w;
-//                   goto gotit;
-//               }
-#warning "this creates more problems than it solves"
             } else if (0 && w->isSticky()) {
+#warning "this creates more problems than it solves"
                 if (pass == 1) {
                     toFocus = w;
                     goto gotit;
@@ -1736,13 +1649,6 @@ void YWindowManager::updateFullscreenLayer() { /// HACK !!!
             w->updateLayer();
         w = w->nextLayer();
     }
-#if 0
-    YFrameWindow *focus = getFocus();
-    while (focus && focus->owner())
-        focus = focus->owner();
-    if (focus)
-        focus->wmRaise();
-#endif
 }
 
 void YWindowManager::restackWindows(YFrameWindow *win) {
@@ -1751,17 +1657,13 @@ void YWindowManager::restackWindows(YFrameWindow *win) {
     YPopupWindow *p;
     long ll;
 
-//    updateFullscreenLayer();
-
     for (f = win; f; f = f->prev())
-        //if (f->visibleNow())
-            count++;
+        count++;
 
     for (ll = win->getActiveLayer() + 1; ll < WinLayerCount; ll++) {
         f = bottom(ll);
         for (; f; f = f->prev())
-            //if (f->visibleNow())
-                count++;
+            count++;
     }
 
 #ifndef LITE
@@ -1834,12 +1736,10 @@ void YWindowManager::restackWindows(YFrameWindow *win) {
 
     for (ll = WinLayerCount - 1; ll > win->getActiveLayer(); ll--) {
         for (f = top(ll); f; f = f->next())
-            //if (f->visibleNow())
-                w[i++] = f->handle();
+            w[i++] = f->handle();
     }
     for (f = top(win->getActiveLayer()); f; f = f->next()) {
-        //if (f->visibleNow())
-            w[i++] = f->handle();
+        w[i++] = f->handle();
         if (f == win)
             break;
     }
@@ -2008,10 +1908,10 @@ void YWindowManager::updateWorkArea() {
                     b = w->y();
                 }
             } else {
-		if (w->x() + int(w->width()) < midX)
-		    l = w->x() + w->width();
-		else if (w->x() > width() - midX)
-		    r = w->x();
+                if (w->x() + int(w->width()) < midX)
+                    l = w->x() + w->width();
+                else if (w->x() > width() - midX)
+                    r = w->x();
             }
             updateArea(ws, l, t, r, b);
         }
@@ -2084,33 +1984,20 @@ void YWindowManager::relocateWindows(long workspace, int dx, int dy) {
             if (f->getWorkspace() == workspace ||
                 (f->isSticky() && workspace == activeWorkspace()))
             {
-                f->setPosition(f->x() + dx, f->y() + dy);
+                f->setNormalPositionOuter(f->x() + dx, f->y() + dy);
             }
         }
 #endif
 }
 
 void YWindowManager::resizeWindows() {
-    for (YFrameWindow * f = topLayer(); f; f = f->nextLayer())
+    for (YFrameWindow * f = topLayer(); f; f = f->nextLayer()) {
         if (f->inWorkArea()) {
-#warning "this needs serious recheck"
-#if 0
-	    if (f->isMaximized() || f->canSize())
-                f->updateLayout();
-#endif
-#if 1
             if (f->isMaximized())
-		f->updateLayout();
-#endif
-#if 0
-	    if (isMaximizedFully())
-		f->setGeometry(fMinX, fMinY, fMaxX - fMinX, fMaxY - fMinY);
-	    else if (f->isMaximizedVert())
-		f->setGeometry(f->x(), fMinY, f->width(), fMaxY - fMinY);
-	    else if (f->isMaximizedHoriz())
-		f->setGeometry(fMinX, f->y(), fMaxX - fMinX, f->height());
-#endif
-	}
+                f->updateDerivedSize();
+                f->updateLayout();
+        }
+    }
 }
 
 void YWindowManager::activateWorkspace(long workspace) {
@@ -2122,7 +2009,7 @@ void YWindowManager::activateWorkspace(long workspace) {
 
 #ifdef CONFIG_TASKBAR
         if (taskBar && taskBar->workspacesPane() &&
-	    fActiveWorkspace != (long)WinWorkspaceInvalid) {
+            fActiveWorkspace != (long)WinWorkspaceInvalid) {
             if (taskBar->workspacesPane()->workspaceButton(fActiveWorkspace))
             {
                 taskBar->workspacesPane()->workspaceButton(fActiveWorkspace)->setPressed(0);
@@ -2180,17 +2067,10 @@ void YWindowManager::activateWorkspace(long workspace) {
 #endif
             }
         unlockFocus();
-	setFocus(toFocus);
+        setFocus(toFocus);
         resetColormap(true);
 
-#ifdef CONFIG_TASKBAR
-        if (taskBar && taskBar->taskPane())
-            taskBar->taskPane()->relayout();
-#endif
-#ifdef CONFIG_TRAY
-        if (taskBar && taskBar->trayPane())
-            taskBar->trayPane()->relayout();
-#endif
+        taskBar->relayoutNow();
 #ifndef LITE
         if (workspaceSwitchStatus
 #ifdef CONFIG_TASKBAR
@@ -2383,8 +2263,8 @@ void YWindowManager::checkLogout() {
         } else if (rebootOrShutdown == 2 && shutdownCommand && shutdownCommand[0]) {
             msg("shutdown ... (%s)", shutdownCommand);
             system(shutdownCommand);
-        }
-        app->exit(0);
+        } else
+            app->exit(0);
     }
 }
 
@@ -2401,7 +2281,7 @@ void YWindowManager::removeClientFrame(YFrameWindow *frame) {
     if (colormapWindow() == frame)
         setColormapWindow(getFocus());
     if (frame->affectsWorkArea())
-	updateWorkArea();
+        updateWorkArea();
 }
 
 void YWindowManager::notifyFocus(YFrameWindow *frame) {
@@ -2520,13 +2400,13 @@ void YWindowManager::tilePlace(YFrameWindow *w, int tx, int ty, int tw, int th)
                 WinStateMaximizedVert |
                 WinStateMaximizedHoriz |
                 WinStateHidden, 0);
-    tw -= 2 * w->borderX();
-    th -= 2 * w->borderY() + w->titleY();
+    tw -= 2 * w->borderXN();
+    th -= 2 * w->borderYN() + w->titleYN();
     w->client()->constrainSize(tw, th, ///WinLayerNormal,
                                0);
-    tw += 2 * w->borderX();
-    th += 2 * w->borderY() + w->titleY();
-    w->setNormalGeometry(tx, ty, tw, th);
+    tw += 2 * w->borderXN();
+    th += 2 * w->borderYN() + w->titleYN();
+    w->setNormalGeometryOuter(tx, ty, tw, th);
 }
 
 void YWindowManager::tileWindows(YFrameWindow **w, int count, bool vertical) {
@@ -2655,10 +2535,10 @@ void YWindowManager::undoArrange() {
             YFrameWindow *f = fArrangeInfo[i].frame;
             if (f) {
                 f->setState(WIN_STATE_ALL, fArrangeInfo[i].state);
-                f->setNormalGeometry(fArrangeInfo[i].x,
-                                     fArrangeInfo[i].y,
-                                     fArrangeInfo[i].w,
-                                     fArrangeInfo[i].h);
+                f->setNormalGeometryOuter(fArrangeInfo[i].x,
+                                          fArrangeInfo[i].y,
+                                          fArrangeInfo[i].w,
+                                          fArrangeInfo[i].h);
             }
         }
         delete [] fArrangeInfo; fArrangeInfo = 0;
@@ -2774,9 +2654,9 @@ void YWindowManager::handleRRScreenChangeNotify(const XRRScreenChangeNotifyEvent
         height() != xrrsc.height)
     {
 
-        msg("xrandr: %d %d",
-            xrrsc.width,
-            xrrsc.height);
+        MSG(("xrandr: %d %d",
+             xrrsc.width,
+             xrrsc.height));
         setSize(xrrsc.width, xrrsc.height);
         updateXineramaInfo();
         updateWorkArea();
