@@ -22,6 +22,8 @@
 YColor *SwitchWindow::switchFg(NULL);
 YColor *SwitchWindow::switchBg(NULL);
 YColor *SwitchWindow::switchHl(NULL);
+YColor *SwitchWindow::switchMbg(NULL);
+YColor *SwitchWindow::switchMfg(NULL);
 
 ref<YFont> SwitchWindow::switchFont;
 
@@ -29,15 +31,26 @@ SwitchWindow * switchWindow(NULL);
 
 SwitchWindow::SwitchWindow(YWindow *parent):
     YPopupWindow(parent) INIT_GRADIENT(fGradient, NULL) {
+    // why this checks here?
     if (switchBg == 0)
         switchBg = new YColor(clrQuickSwitch);
     if (switchFg == 0)
         switchFg = new YColor(clrQuickSwitchText);
-    if (switchHl == 0 && clrQuickSwitchActive)
+    if (/*switchHl == 0 &&*/ clrQuickSwitchActive)
         switchHl = new YColor(clrQuickSwitchActive);
     if (switchFont == null)
         switchFont = YFont::getFont(XFA(switchFontName));
 
+    // I prefer clrNormalMenu but some themes use inverted settings where
+    // clrNormalMenu is the same as clrQuickSwitch
+    if (switchHl)
+        switchMbg = switchHl;
+    else if (!strcmp(clrNormalMenu, clrQuickSwitch))
+        switchMbg = new YColor(clrActiveMenuItem);
+    else
+        switchMbg = new YColor(clrNormalMenu);
+    switchMfg = new YColor(clrActiveTitleBarText);
+
     fActiveWindow = 0;
     fLastWindow = 0;
     modsDown = 0;
@@ -63,17 +76,33 @@ SwitchWindow::~SwitchWindow() {
 
 void SwitchWindow::resize(int xiscreen) {
     int dx, dy, dw, dh;
+
     manager->getScreenGeometry(&dx, &dy, &dw, &dh, xiscreen);
 
     const char *cTitle(fActiveWindow ? fActiveWindow->client()->windowTitle()
-				     : 0);
+                       : 0);
 
     int aWidth =
         quickSwitchSmallWindow ?
         (int) dw * 1/3 : (int) dw * 3/5;
 
-    int tWidth = cTitle ? (int) switchFont->textWidth(cTitle) : 0;
+    int tWidth=0;
+    if (quickSwitchMaxWidth) {
+        for (int i = 0; i < zCount; i++) {
+            if(zList[i]) {
+                const char *title(zList[i]->client()->windowTitle());
+                int oWidth = title ? (int) switchFont->textWidth(title):0;
+                if(oWidth > tWidth) tWidth = oWidth;
+            }
+        }
+    } else {
+        tWidth = cTitle ? switchFont->textWidth(cTitle) : 0;
+    }
 
+#ifndef LITE
+    if (quickSwitchVertical || !quickSwitchAllIcons)
+        tWidth += 2 * quickSwitchIMargin + YIcon::largeSize() + 3;
+#endif
     if (tWidth > aWidth)
         aWidth = tWidth;
 
@@ -81,33 +110,49 @@ void SwitchWindow::resize(int xiscreen) {
     int w = aWidth;
     int h = switchFont->height();
 #ifndef LITE
-    int iWidth =
-        zCount * (YIcon::largeSize() + 2 * quickSwitchIMargin) +
-        (quickSwitchHugeIcon ? YIcon::hugeSize() - YIcon::largeSize() : 0);
 
-    if (iWidth > aWidth)
-        aWidth = iWidth;
+    if (quickSwitchVertical) {
+        w = aWidth;
+        if (w >= mWidth)
+            w = mWidth;
+        w += quickSwitchSepSize;
 
-    int const iHeight =
-        (quickSwitchHugeIcon ?
-         YIcon::hugeSize() : YIcon::largeSize()) + quickSwitchIMargin * 2;
+        int step = (YIcon::largeSize() + 2 * quickSwitchIMargin);
+        int maxHeight = (int) dh - YIcon::largeSize();
+        h = zCount * step;
 
-    if (quickSwitchAllIcons) {
-        if (aWidth > w)
-            w = aWidth;
-    }
-    if (w >= mWidth)
-        w = mWidth;
-    w += quickSwitchHMargin * 2;
+        if (h > maxHeight)
+            h= maxHeight - (maxHeight % step);
+    } else {
 
-    if (quickSwitchAllIcons)
-        h += quickSwitchSepSize + iHeight;
-    else {
-        if (iHeight > h)
-            h = iHeight;
+        int iWidth =
+            zCount * (YIcon::largeSize() + 2 * quickSwitchIMargin) +
+            (quickSwitchHugeIcon ? YIcon::hugeSize() - YIcon::largeSize() : 0);
+
+        int const iHeight =
+            (quickSwitchHugeIcon ?
+             YIcon::hugeSize() : YIcon::largeSize()) + quickSwitchIMargin * 2;
+
+        if (iWidth > aWidth)
+            aWidth = iWidth;
+
+        if (quickSwitchAllIcons) {
+            if (aWidth > w)
+                w = aWidth;
+        }
+        if (w >= mWidth)
+            w = mWidth;
+
+        if (quickSwitchAllIcons)
+            h += quickSwitchSepSize + iHeight;
+        else {
+            if (iHeight > h)
+                h = iHeight;
+        }
     }
 #endif
     h += quickSwitchVMargin * 2;
+    w += quickSwitchHMargin * 2;
 
     setGeometry(YRect(dx + ((dw - w) >> 1),
                       dy + ((dh - h) >> 1),
@@ -138,44 +183,49 @@ void SwitchWindow::paint(Graphics &g, const YRect &/*r*/) {
     else
         g.fillRect(1, 1, width() - 3, height() - 3);
 
+#ifndef LITE
+    // for vertical positioning, continue below. Avoid spagheti code.
+    if(quickSwitchVertical) goto verticalMode;
+#endif
+
     if (fActiveWindow) {
         int tOfs(0);
 
         int ih = 0;
 #ifndef LITE
-	ih = quickSwitchHugeIcon ? YIcon::hugeSize() : YIcon::largeSize();
+        ih = quickSwitchHugeIcon ? YIcon::hugeSize() : YIcon::largeSize();
 
         if (!quickSwitchAllIcons &&
-	    fActiveWindow->clientIcon()) {
+            fActiveWindow->clientIcon()) {
             ref<YIconImage> icon =
                 (quickSwitchHugeIcon && fActiveWindow->clientIcon()->huge() != null)
-		? fActiveWindow->clientIcon()->huge()
-		: fActiveWindow->clientIcon()->large();
+                ? fActiveWindow->clientIcon()->huge()
+                : fActiveWindow->clientIcon()->large();
 
-	    if (icon != null)
-		if (quickSwitchTextFirst) {
-		    g.drawImage(icon,
-			width() - icon->width() - quickSwitchIMargin,
-			(height() - icon->height() - quickSwitchIMargin) / 2);
-		} else {
-		    g.drawImage(icon,
-			quickSwitchIMargin,
-			(height() - icon->height() - quickSwitchIMargin) / 2);
+            if (icon != null)
+                if (quickSwitchTextFirst) {
+                    g.drawImage(icon,
+                                width() - icon->width() - quickSwitchIMargin,
+                                (height() - icon->height() - quickSwitchIMargin) / 2);
+                } else {
+                    g.drawImage(icon,
+                                quickSwitchIMargin,
+                                (height() - icon->height() - quickSwitchIMargin) / 2);
 
-		    tOfs = icon->width() + quickSwitchIMargin
-		         + quickSwitchSepSize;
-		}
+                    tOfs = icon->width() + quickSwitchIMargin
+                        + quickSwitchSepSize;
+                }
 
-		if (quickSwitchSepSize) {
-		    const int ip(icon->width() + 2 * quickSwitchIMargin +
-		    		 quickSwitchSepSize/2);
-		    const int x(quickSwitchTextFirst ? width() - ip : ip);
+            if (quickSwitchSepSize) {
+                const int ip(icon->width() + 2 * quickSwitchIMargin +
+                             quickSwitchSepSize/2);
+                const int x(quickSwitchTextFirst ? width() - ip : ip);
 
-		    g.setColor(switchBg->darker());
-		    g.drawLine(x + 0, 1, x + 0, width() - 2);
-		    g.setColor(switchBg->brighter());
-		    g.drawLine(x + 1, 1, x + 1, width() - 2);
-		}
+                g.setColor(switchBg->darker());
+                g.drawLine(x + 0, 1, x + 0, width() - 2);
+                g.setColor(switchBg->brighter());
+                g.drawLine(x + 1, 1, x + 1, width() - 2);
+            }
         }
 #endif
 
@@ -187,77 +237,67 @@ void SwitchWindow::paint(Graphics &g, const YRect &/*r*/) {
         if (cTitle) {
             const int x = max((width() - tOfs -
                                switchFont->textWidth(cTitle)) >> 1, 0) + tOfs;
-	    const int y(quickSwitchAllIcons
-	    	      ? quickSwitchTextFirst
-		      ? quickSwitchVMargin + switchFont->ascent()
-		      : height() - quickSwitchVMargin - switchFont->descent()
-		      : ((height() + switchFont->height()) >> 1) -
-		        switchFont->descent());
+            const int y(quickSwitchAllIcons
+                        ? quickSwitchTextFirst
+                        ? quickSwitchVMargin + switchFont->ascent()
+                        : height() - quickSwitchVMargin - switchFont->descent()
+                        : ((height() + switchFont->height()) >> 1) -
+                        switchFont->descent());
 
             g.drawChars(cTitle, 0, strlen(cTitle), x, y);
 
 #ifndef LITE
-	    if (quickSwitchAllIcons && quickSwitchSepSize) {
-		int const h(quickSwitchVMargin + ih +
-			    quickSwitchIMargin * 2 +
-			    quickSwitchSepSize / 2);
-		int const y(quickSwitchTextFirst ? height() - h : h);
+            if (quickSwitchAllIcons && quickSwitchSepSize) {
+                int const h(quickSwitchVMargin + ih +
+                            quickSwitchIMargin * 2 +
+                            quickSwitchSepSize / 2);
+                int const y(quickSwitchTextFirst ? height() - h : h);
 
-		g.setColor(switchBg->darker());
-		g.drawLine(1, y + 0, width() - 2, y + 0);
-		g.setColor(switchBg->brighter());
-		g.drawLine(1, y + 1, width() - 2, y + 1);
+                g.setColor(switchBg->darker());
+                g.drawLine(1, y + 0, width() - 2, y + 0);
+                g.setColor(switchBg->brighter());
+                g.drawLine(1, y + 1, width() - 2, y + 1);
             }
 #endif
         }
 
 #ifndef LITE
-	if (quickSwitchAllIcons) {
-	    int const ds(quickSwitchHugeIcon ? YIcon::hugeSize() -
-	    				       YIcon::largeSize() : 0);
-	    int const dx(YIcon::largeSize() + 2 * quickSwitchIMargin);
+        if (quickSwitchAllIcons) {
+            int const ds(quickSwitchHugeIcon ? YIcon::hugeSize() -
+                         YIcon::largeSize() : 0);
+            int const dx(YIcon::largeSize() + 2 * quickSwitchIMargin);
 
-	    const int visIcons((width() - 2 * quickSwitchHMargin) / dx);
-	    int curIcon(-1);
+            const int visIcons((width() - 2 * quickSwitchHMargin) / dx);
+            int curIcon(-1);
 
-#if 0
-	    YFrameWindow * first(nextWindow(NULL, true, false));
-	    YFrameWindow * frame(first);
+            int const y(quickSwitchTextFirst
+                        ? height() - quickSwitchVMargin - ih - quickSwitchIMargin + ds / 2
+                        : quickSwitchVMargin + ds + quickSwitchIMargin - ds / 2);
 
-	    do {
-		if (frame == fActiveWindow) curIcon = fIconCount;
-		++fIconCount;
-	    } while ((frame = nextWindow(frame, true, true)) != first);
-#endif
+            g.setColor(switchHl ? switchHl : switchBg->brighter());
 
-	    int const y(quickSwitchTextFirst
-		? height() - quickSwitchVMargin - ih - quickSwitchIMargin + ds / 2
-		: quickSwitchVMargin + ds + quickSwitchIMargin - ds / 2);
+            const int off(max(1 + curIcon - visIcons, 0));
+            const int end(off + visIcons);
 
-	    g.setColor(switchHl ? switchHl : switchBg->brighter());
-
-	    const int off(max(1 + curIcon - visIcons, 0));
-	    const int end(off + visIcons);
-
-	    int x((width() - min(visIcons, zCount) * dx - ds) /  2 +
-	    	   quickSwitchIMargin);
+            int x((width() - min(visIcons, zCount) * dx - ds) /  2 +
+                  quickSwitchIMargin);
 
             for (int i = 0; i < zCount; i++) {
                 YFrameWindow *frame = zList[i];
 
-	    	if (frame->clientIcon()) {
-		    if (i >= off && i < end) {
-			if (frame == fActiveWindow) {
-			    if (quickSwitchFillSelection)
-				g.fillRect(x - quickSwitchIBorder,
-					   y - quickSwitchIBorder - ds/2,
-					   ih + 2 * quickSwitchIBorder,
-					   ih + 2 * quickSwitchIBorder);
-			    else
-				g.drawRect(x - quickSwitchIBorder,
-					   y - quickSwitchIBorder - ds/2,
-					   ih + 2 * quickSwitchIBorder,
-					   ih + 2 * quickSwitchIBorder);
+                if (frame->clientIcon()) {
+                    if (i >= off && i < end) {
+                        if (frame == fActiveWindow) {
+                            if (quickSwitchFillSelection)
+                                g.fillRect(x - quickSwitchIBorder,
+                                           y - quickSwitchIBorder - ds/2,
+                                           ih + 2 * quickSwitchIBorder,
+                                           ih + 2 * quickSwitchIBorder);
+                            else
+                                g.drawRect(x - quickSwitchIBorder,
+                                           y - quickSwitchIBorder - ds/2,
+                                           ih + 2 * quickSwitchIBorder,
+                                           ih + 2 * quickSwitchIBorder);
 
                             ref<YIconImage> icon =
                                 (quickSwitchHugeIcon &&
@@ -268,21 +308,96 @@ void SwitchWindow::paint(Graphics &g, const YRect &/*r*/) {
                             if (icon != null)
                                 g.drawImage(icon, x, y - ds/2);
 
-			    x+= ds;
-			} else {
-			    ref<YIconImage> icon = frame->clientIcon()->large();
+                            x+= ds;
+                        } else {
+                            ref<YIconImage> icon = frame->clientIcon()->large();
                             if (icon != null)
                                 g.drawImage(icon, x, y);
-			}
+                        }
 
-			x += dx;
-		    }
+                        x += dx;
+                    }
                 }
             }
-//	    } while ((frame = nextWindow(frame, true, true)) != first);
+            //      {} while ((frame = nextWindow(frame, true, true)) != first);
         }
 #endif
     }
+
+#ifndef LITE
+    return;
+
+verticalMode:
+    if (fActiveWindow) {
+
+        int ih = 0;
+        //ih = quickSwitchHugeIcon ? YIcon::hugeSize() : YIcon::largeSize();
+        ih = YIcon::largeSize();
+
+        int pos = quickSwitchVMargin;
+        g.setFont(switchFont);
+        g.setColor(switchFg);
+
+        for (int i = 0; i < zCount; i++) {
+            YFrameWindow *frame = zList[i];
+
+            g.setColor(switchFg);
+            if(frame == fActiveWindow) {
+                g.setColor(switchMbg);
+                g.fillRect(quickSwitchHMargin, pos + quickSwitchVMargin , width() - quickSwitchHMargin*2, ih + quickSwitchIMargin );
+                g.setColor(switchMfg);
+            }
+
+            const char *cTitle(frame->client()->windowTitle());
+
+            if (cTitle) {
+                const int x(1+ih + quickSwitchIMargin *2 + quickSwitchHMargin + quickSwitchSepSize);
+                const int y(pos + quickSwitchIMargin +  quickSwitchVMargin + ih/2);
+
+                g.drawChars(cTitle, 0, strlen(cTitle), x, y);
+
+            }
+            if (frame->clientIcon()) {
+
+                ref<YIconImage> icon =
+                    frame->clientIcon()->large();
+
+                if (icon != null)
+                    if (quickSwitchTextFirst) {
+
+                        // prepaint icons because of too long strings
+                        g.setColor( (frame == fActiveWindow) ? switchMfg : switchMbg);
+                        g.fillRect(
+                                   width() - ih - quickSwitchIMargin *2 - quickSwitchHMargin,
+                                   pos + quickSwitchVMargin,
+                                   ih + 2 * quickSwitchIMargin,
+                                   ih + quickSwitchIMargin);
+
+                        g.drawImage(icon,
+                                    width() - ih - quickSwitchIMargin - quickSwitchHMargin,
+                                    pos + quickSwitchIMargin);
+                    } else {
+                        g.drawImage(icon,
+                                    quickSwitchIMargin,
+                                    pos + quickSwitchIMargin);
+                    }
+            }
+
+            pos += ih + 2* quickSwitchIMargin;
+        }
+
+        if (quickSwitchSepSize) {
+            const int ip(ih + 2 * quickSwitchIMargin +
+                         quickSwitchSepSize/2);
+            const int x(quickSwitchTextFirst ? width() - ip : ip);
+
+            g.setColor(switchBg->darker());
+            g.drawLine(x + 0, 1, x + 0, height() - 2);
+            g.setColor(switchBg->brighter());
+            g.drawLine(x + 1, 1, x + 1, height() - 2);
+        }
+    }
+#endif
 }
 
 int SwitchWindow::getZListCount() {
@@ -358,18 +473,6 @@ int SwitchWindow::GetZListWorkspace(YFrameWindow **list, int max,
                 if (pass == 2)
                     if (quickSwitchToMinimized)
                         list[count++] = w;
-#if 0
-//            } else if (w->visibleNow()) {
-//                if (pass == 1) list[count++] = w;
-#endif
-#if 0
-//            } else if (!w->isSticky() &&
-//                       w->getWorkspace() != fRoot->activeWorkspace() &&
-//                       (!quickSwitchToAllWorkspaces || quickSwitchGroupWorkspaces)) {
-//                if (pass == 9)
-//                    if (quickSwitchToAllWorkspaces)
-//                        list[count++] = w;
-#endif
             } else {
                 if (pass == 1) list[count++] = w;
             }
@@ -405,66 +508,66 @@ void SwitchWindow::freeZList() {
 }
 
 /*
-YFrameWindow *SwitchWindow::nextWindow(YFrameWindow *from, bool zdown, bool next) {
-    if (from == 0) {
-        next = false;
-        from = zdown ? manager->topLayer() : manager->bottomLayer();
-    }
-    int flags =
-        YFrameWindow::fwfFocusable |
-        (quickSwitchToAllWorkspaces ? 0 : YFrameWindow::fwfWorkspace) |
-        YFrameWindow::fwfLayers |
-        YFrameWindow::fwfSwitchable |
-        (next ? YFrameWindow::fwfNext: 0) |
-        (zdown ? 0 : YFrameWindow::fwfBackward);
+ YFrameWindow *SwitchWindow::nextWindow(YFrameWindow *from, bool zdown, bool next) {
+ if (from == 0) {
+ next = false;
+ from = zdown ? manager->topLayer() : manager->bottomLayer();
+ }
+ int flags =
+ YFrameWindow::fwfFocusable |
+ (quickSwitchToAllWorkspaces ? 0 : YFrameWindow::fwfWorkspace) |
+ YFrameWindow::fwfLayers |
+ YFrameWindow::fwfSwitchable |
+ (next ? YFrameWindow::fwfNext: 0) |
+ (zdown ? 0 : YFrameWindow::fwfBackward);
 
-    YFrameWindow *n = 0;
+ YFrameWindow *n = 0;
 
-    if (from == 0)
-        return 0;
+ if (from == 0)
+ return 0;
 
-    if (zdown) {
-        n = from->findWindow(flags | YFrameWindow::fwfUnminimized | YFrameWindow::fwfNotHidden);
-        if (n == 0 && quickSwitchToMinimized)
-            n = from->findWindow(flags | YFrameWindow::fwfMinimized | YFrameWindow::fwfNotHidden);
-        if (n == 0 && quickSwitchToHidden)
-            n = from->findWindow(flags | YFrameWindow::fwfHidden);
-        if (n == 0) {
-            flags |= YFrameWindow::fwfCycle;
-            n = from->findWindow(flags | YFrameWindow::fwfUnminimized | YFrameWindow::fwfNotHidden);
-            if (n == 0 && quickSwitchToMinimized)
-                n = from->findWindow(flags | YFrameWindow::fwfMinimized | YFrameWindow::fwfNotHidden);
-            if (n == 0 && quickSwitchToHidden)
-                n = from->findWindow(flags | YFrameWindow::fwfHidden);
-        }
-    } else {
-        if (n == 0 && quickSwitchToHidden)
-            n = from->findWindow(flags | YFrameWindow::fwfHidden);
-        if (n == 0 && quickSwitchToMinimized)
-            n = from->findWindow(flags | YFrameWindow::fwfMinimized | YFrameWindow::fwfNotHidden);
-        if (n == 0)
-            n = from->findWindow(flags | YFrameWindow::fwfUnminimized | YFrameWindow::fwfNotHidden);
-        if (n == 0) {
-            flags |= YFrameWindow::fwfCycle;
-            if (n == 0 && quickSwitchToHidden)
-                n = from->findWindow(flags | YFrameWindow::fwfHidden);
-            if (n == 0 && quickSwitchToMinimized)
-                n = from->findWindow(flags | YFrameWindow::fwfMinimized | YFrameWindow::fwfNotHidden);
-            if (n == 0)
-                n = from->findWindow(flags | YFrameWindow::fwfUnminimized | YFrameWindow::fwfNotHidden);
-        }
-    }
-    if (n == 0)
-        n = from->findWindow(flags |
-                             YFrameWindow::fwfVisible |
-                             (quickSwitchToMinimized) ? 0 : YFrameWindow::fwfUnminimized |
-                             YFrameWindow::fwfSame);
-    if (n == 0)
-        n = fLastWindow;
+ if (zdown) {
+ n = from->findWindow(flags | YFrameWindow::fwfUnminimized | YFrameWindow::fwfNotHidden);
+ if (n == 0 && quickSwitchToMinimized)
+ n = from->findWindow(flags | YFrameWindow::fwfMinimized | YFrameWindow::fwfNotHidden);
+ if (n == 0 && quickSwitchToHidden)
+ n = from->findWindow(flags | YFrameWindow::fwfHidden);
+ if (n == 0) {
+ flags |= YFrameWindow::fwfCycle;
+ n = from->findWindow(flags | YFrameWindow::fwfUnminimized | YFrameWindow::fwfNotHidden);
+ if (n == 0 && quickSwitchToMinimized)
+ n = from->findWindow(flags | YFrameWindow::fwfMinimized | YFrameWindow::fwfNotHidden);
+ if (n == 0 && quickSwitchToHidden)
+ n = from->findWindow(flags | YFrameWindow::fwfHidden);
+ }
+ } else {
+ if (n == 0 && quickSwitchToHidden)
+ n = from->findWindow(flags | YFrameWindow::fwfHidden);
+ if (n == 0 && quickSwitchToMinimized)
+ n = from->findWindow(flags | YFrameWindow::fwfMinimized | YFrameWindow::fwfNotHidden);
+ if (n == 0)
+ n = from->findWindow(flags | YFrameWindow::fwfUnminimized | YFrameWindow::fwfNotHidden);
+ if (n == 0) {
+ flags |= YFrameWindow::fwfCycle;
+ if (n == 0 && quickSwitchToHidden)
+ n = from->findWindow(flags | YFrameWindow::fwfHidden);
+ if (n == 0 && quickSwitchToMinimized)
+ n = from->findWindow(flags | YFrameWindow::fwfMinimized | YFrameWindow::fwfNotHidden);
+ if (n == 0)
+ n = from->findWindow(flags | YFrameWindow::fwfUnminimized | YFrameWindow::fwfNotHidden);
+ }
+ }
+ if (n == 0)
+ n = from->findWindow(flags |
+ YFrameWindow::fwfVisible |
+ (quickSwitchToMinimized) ? 0 : YFrameWindow::fwfUnminimized |
+ YFrameWindow::fwfSame);
+ if (n == 0)
+ n = fLastWindow;
 
-    return n;
-}
-*/
+ return n;
+ }
+ */
 
 YFrameWindow *SwitchWindow::nextWindow(bool zdown) {
     if (zdown) {
@@ -485,15 +588,15 @@ YFrameWindow *SwitchWindow::nextWindow(bool zdown) {
 
 void SwitchWindow::begin(bool zdown, int mods) {
     modsDown = mods & (xapp->AltMask | xapp->MetaMask |
-    		       xapp->HyperMask | xapp->SuperMask |
-		       ControlMask);
+                       xapp->HyperMask | xapp->SuperMask |
+                       ControlMask);
 
     if (isUp) {
         cancelPopup();
         isUp = false;
         return;
     }
-    
+
     int xiscreen = manager->getScreen();
 
     fLastWindow = fActiveWindow = manager->getFocus();
@@ -501,32 +604,6 @@ void SwitchWindow::begin(bool zdown, int mods) {
     zTarget = 0;
     fActiveWindow = nextWindow(zdown);
 
-#if 0
-    if (fActiveWindow &&
-        (!fActiveWindow->isFocusable() || /* !!! fix? */
-         !(quickSwitchToAllWorkspaces || fActiveWindow->visibleNow()) ||
-#ifndef NO_WINDOW_OPTIONS
-         (fActiveWindow->frameOptions() & YFrameWindow::foIgnoreQSwitch) ||
-#endif
-         (!quickSwitchToMinimized && fActiveWindow->isMinimized()) ||
-         (!quickSwitchToHidden && fActiveWindow->isHidden()))) {
-        fActiveWindow = NULL;
-        app->alert();
-    }
-
-    fIconCount = fIconOffset = 0;
-
-    if (quickSwitchAllIcons && fActiveWindow) {
-        YFrameWindow * frame(fActiveWindow); do {
-            if (fActiveWindow->clientIcon() &&
-                fActiveWindow->clientIcon()->large())
-                ++fIconCount;
-        } while ((frame = nextWindow(frame, zdown, true)) != fActiveWindow);
-    }
-
-    MSG(("fIconCount: %d, fIconOffset: %d", fIconCount, fIconOffset));
-#endif
-
     resize(xiscreen);
 
     if (fActiveWindow) {
@@ -589,7 +666,7 @@ void SwitchWindow::displayFocus(YFrameWindow *frame) {
 
 void SwitchWindow::destroyedFrame(YFrameWindow *frame) {
     if (zList == 0)
-	return;
+        return;
     if (frame == fLastWindow)
         fLastWindow = 0;
     updateZList();
