@@ -94,13 +94,13 @@ static void initPixmaps() {
 
 #ifdef CONFIG_GRADIENTS
     if (taskbackPixbuf == null)
-	taskbackPixmap = subdirs.loadPixmap(base, "taskbarbg.xpm");
+        taskbackPixmap = subdirs.loadPixmap(base, "taskbarbg.xpm");
     if (taskbuttonPixbuf == null)
-	taskbuttonPixmap = subdirs.loadPixmap(base, "taskbuttonbg.xpm");
+        taskbuttonPixmap = subdirs.loadPixmap(base, "taskbuttonbg.xpm");
     if (taskbuttonactivePixbuf == null)
-	taskbuttonactivePixmap = subdirs.loadPixmap(base, "taskbuttonactive.xpm");
+        taskbuttonactivePixmap = subdirs.loadPixmap(base, "taskbuttonactive.xpm");
     if (taskbuttonminimizedPixbuf == null)
-	taskbuttonminimizedPixmap = subdirs.loadPixmap(base, "taskbuttonminimized.xpm");
+        taskbuttonminimizedPixmap = subdirs.loadPixmap(base, "taskbuttonminimized.xpm");
 #else
     taskbackPixmap = subdirs.loadPixmap(base, "taskbarbg.xpm");
     taskbuttonPixmap = subdirs.loadPixmap(base, "taskbuttonbg.xpm");
@@ -144,7 +144,7 @@ static void initPixmaps() {
 
 TaskBar::TaskBar(YWindow *aParent):
 #if 1
-    YFrameClient(aParent, 0) INIT_GRADIENT(fGradient, NULL)
+YFrameClient(aParent, 0) INIT_GRADIENT(fGradient, NULL)
 #else
     YWindow(aParent) INIT_GRADIENT(fGradient, NULL)
 #endif
@@ -152,6 +152,7 @@ TaskBar::TaskBar(YWindow *aParent):
     taskBar = this;
     fIsMapped = false;
     fIsHidden = taskBarAutoHide;
+    fIsCollapsed = false;
     fMenuShown = false;
     fNeedRelayout = false;
     fAddressBar = 0;
@@ -171,14 +172,13 @@ TaskBar::TaskBar(YWindow *aParent):
     setClassHint("icewm", "TaskBar");
     setWinStateHint(WinStateAllWorkspaces, WinStateAllWorkspaces);
     //!!!setWinStateHint(WinStateDockHorizontal, WinStateDockHorizontal);
+
     setWinHintsHint(WinHintsSkipFocus |
-    		    WinHintsSkipWindowMenu |
-    		    WinHintsSkipTaskBar |
-		    (taskBarAutoHide ? 0 : WinHintsDoNotCover));
+                    WinHintsSkipWindowMenu |
+                    WinHintsSkipTaskBar);
 
     setWinWorkspaceHint(0);
-    setWinLayerHint(taskBarAutoHide ? WinLayerAboveDock :
-		    taskBarKeepBelow ? WinLayerBelow : WinLayerDock);
+    setWinLayerHint(WinLayerAboveDock);
 
     {
         XWMHints wmh;
@@ -211,7 +211,7 @@ TaskBar::TaskBar(YWindow *aParent):
             MWM_FUNC_MOVE /*|
             MWM_FUNC_RESIZE*/;
         mwm.decorations = 0;
-            //MWM_DECOR_BORDER /*|MWM_DECOR_RESIZEH*/;
+        //MWM_DECOR_BORDER /*|MWM_DECOR_RESIZEH*/;
 
         setMwmHints(mwm);
     }
@@ -237,7 +237,6 @@ TaskBar::TaskBar(YWindow *aParent):
 
     initMenu();
     initApplets();
-    updateLayout();
 
     getPropertiesList();
     getWMHints();
@@ -340,8 +339,8 @@ void TaskBar::initMenu() {
 
         taskBarMenu->addItem(_("_About"), -2, actionAbout, 0);
 #endif
-	if (logoutMenu) {
-	    taskBarMenu->addSeparator();
+        if (logoutMenu) {
+            taskBarMenu->addSeparator();
             if (showLogoutSubMenu)
                 taskBarMenu->addItem(_("_Logout..."), -2, actionLogout, logoutMenu);
             else
@@ -362,19 +361,19 @@ void TaskBar::initApplets() {
     fNetStatus = 0;
 #ifdef HAVE_NET_STATUS
     if (taskBarShowNetStatus && netDevice) {
-	unsigned cnt(strtoken(netDevice));
+        unsigned cnt(strtoken(netDevice));
 
-	if (cnt) {
-	    fNetStatus = new NetStatus*[cnt + 1];
-	    fNetStatus[cnt--] = NULL;
+        if (cnt) {
+            fNetStatus = new NetStatus*[cnt + 1];
+            fNetStatus[cnt--] = NULL;
 
-	    for (char const * s(netDevice + strspn(netDevice, " \t"));
-		 *s != '\0'; s = strnxt(s)) {
-		 char const * netdev(newstr(s, " \t"));
-		 fNetStatus[cnt--] = new NetStatus(netdev, this);
-		 delete[] netdev;
-	     }
-	}
+            for (char const * s(netDevice + strspn(netDevice, " \t"));
+                 *s != '\0'; s = strnxt(s)) {
+                char const * netdev(newstr(s, " \t"));
+                fNetStatus[cnt--] = new NetStatus(netdev, this);
+                delete[] netdev;
+            }
+        }
     }
 #endif
 #endif
@@ -393,38 +392,48 @@ void TaskBar::initApplets() {
         fApm = 0;
 #endif
 
+    if (taskBarShowCollapseButton) {
+        fCollapseButton = new YButton(this, actionCollapseTaskbar);
+        if (fCollapseButton) {
+            fCollapseButton->setText(">");
+            fCollapseButton->setActionListener(this);
+        }
+    } else
+        fCollapseButton = 0;
+
 #ifdef CONFIG_APPLET_MAILBOX
     fMailBoxStatus = 0;
 
     if (taskBarShowMailboxStatus) {
-	char const * mailboxes(mailBoxPath ? mailBoxPath : getenv("MAIL"));
-	unsigned cnt(strtoken(mailboxes));
+        char const * mailboxes(mailBoxPath ? mailBoxPath : getenv("MAIL"));
+        unsigned cnt(strtoken(mailboxes));
 
-	if (cnt) {
-	    fMailBoxStatus = new MailBoxStatus*[cnt + 1];
+        if (cnt) {
+            fMailBoxStatus = new MailBoxStatus*[cnt + 1];
             fMailBoxStatus[cnt--] = NULL;
 
-	    for (char const * s(mailboxes + strspn(mailboxes, " \t"));
-		 *s != '\0'; s = strnxt(s)) {
-		char * mailbox(newstr(s, " \t"));
-		fMailBoxStatus[cnt--] = new MailBoxStatus(mailbox, this);
-		delete[] mailbox;
-	    }
-	} else if (getenv("MAIL")) {
-	    fMailBoxStatus = new MailBoxStatus*[2];
+            for (char const * s(mailboxes + strspn(mailboxes, " \t"));
+                 *s != '\0'; s = strnxt(s))
+            {
+                char * mailbox(newstr(s, " \t"));
+                fMailBoxStatus[cnt--] = new MailBoxStatus(mailbox, this);
+                delete[] mailbox;
+            }
+        } else if (getenv("MAIL")) {
+            fMailBoxStatus = new MailBoxStatus*[2];
             fMailBoxStatus[0] = new MailBoxStatus(getenv("MAIL"), this);
             fMailBoxStatus[1] = NULL;
-	} else if (getlogin()) {
-	    char * mbox = strJoin("/var/spool/mail/", getlogin(), NULL);
+        } else if (getlogin()) {
+            char * mbox = strJoin("/var/spool/mail/", getlogin(), NULL);
 
-	    if (!access(mbox, R_OK)) {
-		fMailBoxStatus = new MailBoxStatus*[2];
-		fMailBoxStatus[0] = new MailBoxStatus(mbox, this);
-		fMailBoxStatus[1] = NULL;
-	    }
+            if (!access(mbox, R_OK)) {
+                fMailBoxStatus = new MailBoxStatus*[2];
+                fMailBoxStatus[0] = new MailBoxStatus(mbox, this);
+                fMailBoxStatus[1] = NULL;
+            }
 
-	    delete[] mbox;
-	}
+            delete[] mbox;
+        }
     }
 #endif
 #ifndef NO_CONFIGURE_MENUS
@@ -432,7 +441,7 @@ void TaskBar::initApplets() {
         fApplications = new ObjectButton(this, rootMenu);
         fApplications->setActionListener(this);
         fApplications->setImage(icewmImage);
-	fApplications->setToolTip(_("Favorite applications"));
+        fApplications->setToolTip(_("Favorite applications"));
     } else
         fApplications = 0;
 
@@ -450,7 +459,7 @@ void TaskBar::initApplets() {
         fWinList = new ObjectButton(this, windowListMenu);
         fWinList->setImage(windowsImage);
         fWinList->setActionListener(this);
-	fWinList->setToolTip(_("Window list menu"));
+        fWinList->setToolTip(_("Window list menu"));
     } else
         fWinList = 0;
 #endif
@@ -460,7 +469,7 @@ void TaskBar::initApplets() {
         fShowDesktop->setImage(showDesktopImage);
         fShowDesktop->setActionListener(wmapp);
         fShowDesktop->setToolTip(_("Show Desktop"));
-    } 
+    }
     if (taskBarShowWorkspaces && workspaceCount > 0) {
         fWorkspaces = new WorkspacesPane(this);
     } else
@@ -486,339 +495,177 @@ void TaskBar::initApplets() {
 }
 
 void TaskBar::trayChanged() {
-    updateLayout();
+    relayout();
+    //    updateLayout();
 }
 
-void TaskBar::updateLayout() {
-    int ht = 26;
-
-    setSize(1, ht);
-#ifdef CONFIG_APPLET_CLOCK
-    if (fClock) {
-        if (fClock->height() > ht)
-            ht = fClock->height();
-    }
+void TaskBar::updateLayout(int &size_w, int &size_h) {
+    struct {
+        YWindow *w;
+        bool left;
+        int row; // 0 = bottom, 1 = top
+        bool show;
+        int pre, post;
+        bool expand;
+    } *wl, wlist[] = {
+#ifndef NO_CONFIGURE_MENUS
+        { fApplications, true, 1, true, 0, 0, true },
+#endif
+        { fShowDesktop, true, 0, true, 0, 0, true },
+#ifdef CONFIG_WINMENU
+        { fWinList, true, 0, true, 0, 0, true},
 #endif
 #ifndef NO_CONFIGURE_MENUS
-    if (fApplications) {
-        if (fApplications->height() > ht)
-            ht = fApplications->height();
-    }
+        { fObjectBar, true, 1, true, 4, 0, true },
 #endif
-#ifdef CONFIG_WINMENU
-    if (fWinList) {
-        if (fWinList->height() > ht)
-            ht = fWinList->height();
-    }
-#endif
-#ifdef CONFIG_APPLET_APM
-    if (fApm) {
-        if (fApm->height() > ht)
-            ht = fApm->height();
-    }
-#endif
-    if (taskBarDoubleHeight) {
-        {
-            int dx, dy, dw, dh;
-            manager->getScreenGeometry(&dx, &dy, &dw, &dh);
-            setSize(dw, 2 * ht + 2);
-        }
+        { fWorkspaces, taskBarWorkspacesLeft, 0, true, 4, 4, true },
 
-        updateLocation();
-
-        leftX = 0;
-        rightX = width() - 2;
+        { fCollapseButton, false, 0, true, 0, 2, true },
 #ifdef CONFIG_APPLET_CLOCK
-        if (fClock) {
-            fClock->setPosition(rightX - fClock->width(),
-                                (ht - fClock->height()) / 2);
-            fClock->show();
-            rightX -= fClock->width() + 2;
-        }
-#endif
-	if (fWorkspaces && !taskBarWorkspacesLeft) {
-            fWorkspaces->setPosition(rightX - fWorkspaces->width(), (ht - fWorkspaces->height()) / 2);
-            rightX -= fWorkspaces->width() + 4;
-           fWorkspaces->show();
-        }
-#ifdef CONFIG_APPLET_APM
-        if (fApm) {
-            rightX -= 2;
-            fApm->setPosition(rightX - fApm->width(),
-                              (ht - fApm->height()) / 2);
-            fApm->show();
-            rightX -= fApm->width() + 2;
-        }
+        { fClock, false, 1, true, 2, 2, false },
 #endif
 #ifdef CONFIG_APPLET_MAILBOX
-        if (fMailBoxStatus)
-	    for (MailBoxStatus ** mbox(fMailBoxStatus); *mbox; ++mbox) {
-		(*mbox)->setPosition(rightX - (*mbox)->width() - 1,
-                                  (ht - (*mbox)->height()) / 2);
-
-		(*mbox)->show();
-		rightX -= (*mbox)->width() + 2;
-	    }
+        { fMailBoxStatus ? fMailBoxStatus[0] : 0, false, 1, true, 1, 1, false },
+#warning "a hack"
+        { fMailBoxStatus && fMailBoxStatus[0] ? fMailBoxStatus[1] : 0, false, 1, true, 1, 1, false },
+        { fMailBoxStatus && fMailBoxStatus[0] && fMailBoxStatus[1] ? fMailBoxStatus[2] : 0, false, 1, true, 1, 1, false },
 #endif
 #ifdef CONFIG_APPLET_CPU_STATUS
-        if (fCPUStatus) {
-            fCPUStatus->setPosition(rightX - fCPUStatus->width() - 1,
-                                    (ht - fCPUStatus->height()) / 2);
-            fCPUStatus->show();
-            rightX -= fCPUStatus->width() + 2;
-        }
+        { fCPUStatus, false, 1, true, 2, 2, false },
 #endif
-
 #ifdef CONFIG_APPLET_NET_STATUS
-        if (fNetStatus) {
-	    for (NetStatus ** netstat(fNetStatus); *netstat; ++netstat) {
-		rightX -= 2;
-
-		(*netstat)->setPosition(rightX - (*netstat)->width() - 1,
-				  (ht - (*netstat)->height()) / 2);
-
-		// don't do a show() here because PPPStatus takes care of it
-		rightX -= (*netstat)->width() + 2;
-            }
-        }
-#endif
-
-        if (fApplications) {
-            fApplications->setPosition(leftX, 1);
-            fApplications->show();
-            leftX += fApplications->width();
-        }
-#ifndef NO_CONFIGURE_MENUS
-        if (fObjectBar) {
-//            fObjectBar->setSize(1, ht);
-            leftX += 2;
-            fObjectBar->setPosition(leftX, 1);
-            fObjectBar->show();
-            leftX += fObjectBar->width() + 4;
-        }
-#endif
-
-#ifdef CONFIG_ADDRESSBAR
-        if (fAddressBar) {
-            if (1) {
-                leftX += 2;
-                fAddressBar->setGeometry(
-                    YRect(leftX,
-                          1 + (ht - fAddressBar->height()) / 2,
-                          rightX - leftX - 4,
-                          fAddressBar->height()));
-
-                if (showAddressBar) {
-                    fAddressBar->show();
-                }
-            } else {
-                //fAddressBar->setGeometry(2, 2, width() - 4, height() - 4);
-            }
-        }
-#endif
-
-        leftX = 0;
-        rightX = width() - 1;
-
-#ifdef CONFIG_WINMENU
-        if (fWinList) {
-            fWinList->setPosition(leftX,
-                                  height() - 1 - fWinList->height());
-            fWinList->show();
-            leftX += fWinList->width() + 4;
-        }
-#endif
-        if (fShowDesktop) {
-            fShowDesktop->setGeometry(YRect(leftX, height() - 1 - fShowDesktop->height(), fShowDesktop->width(), ht - 2));
-            fShowDesktop->show();
-            leftX += fShowDesktop->width() + 4;
-        }
-
-        if (fWorkspaces && taskBarWorkspacesLeft) {
-            fWorkspaces->setPosition(leftX, height() - 1 - fWorkspaces->height());
-            leftX += fWorkspaces->width() + 4;
-            fWorkspaces->show();
-        }
-    } else {
-        {
-            int dx, dy, dw, dh;
-            manager->getScreenGeometry(&dx, &dy, &dw, &dh);
-            setSize(dw, ht);
-        }
-
-        updateLocation();
-
-        leftX = 0;
-        rightX = width() - 2;
-#ifdef CONFIG_APPLET_CLOCK
-        if (fClock) {
-            fClock->setPosition(rightX - fClock->width(),
-                                (ht - fClock->height()) / 2);
-            fClock->show();
-            rightX -= fClock->width() + 2;
-        }
-#endif
-	if (fWorkspaces && !taskBarWorkspacesLeft) {
-            fWorkspaces->setPosition(rightX - fWorkspaces->width(), height() - fWorkspaces->height());
-            rightX -= fWorkspaces->width() + 4;
-           fWorkspaces->show();
-        }
 #ifdef CONFIG_APPLET_MAILBOX
-        if (fMailBoxStatus) {
-	    for (MailBoxStatus ** mbox(fMailBoxStatus); *mbox; ++mbox) {
-		(*mbox)->setPosition(rightX - (*mbox)->width() - 1,
-				  (ht - (*mbox)->height()) / 2);
-
-		(*mbox)->show();
-		rightX -= (*mbox)->width() + 2;
-            }
-        }
+        { fNetStatus ? fNetStatus[0] : 0, false, 1, true, 1, 1, false },
+#warning "a hack"
+        { fNetStatus && fNetStatus[0] ? fNetStatus[1] : 0, false, 1, true, 1, 1, false },
+        { fNetStatus && fNetStatus[0] && fNetStatus[1] ? fNetStatus[2] : 0, false, 1, true, 1, 1, false },
 #endif
-#ifdef CONFIG_APPLET_CPU_STATUS
-        if (fCPUStatus) {
-            fCPUStatus->setPosition(rightX - fCPUStatus->width() - 1,
-                                    (ht - fCPUStatus->height()) / 2);
-            fCPUStatus->show();
-            rightX -= fCPUStatus->width() + 2;
-        }
-#endif
-#ifdef HAVE_NET_STATUS
-        if (fNetStatus)
-	    for (NetStatus ** netstat(fNetStatus); *netstat; ++netstat) {
-		rightX -= 2;
-
-		(*netstat)->setPosition(rightX - (*netstat)->width() - 1,
-                                        (ht - (*netstat)->height()) / 2);
-
-		// don't do a show() here because PPPStatus takes care of it
-		rightX -= (*netstat)->width() + 2;
-            }
 #endif
 #ifdef CONFIG_APPLET_APM
-        if (fApm) {
-            rightX -= 2;
-            fApm->setPosition(rightX - fApm->width(),
-                              (ht - fApm->height()) / 2);
-            fApm->show();
-            rightX -= fApm->width() + 2;
-        }
+        { fApm, false, 1, true, 0, 2, false },
 #endif
-        if (fApplications) {
-            fApplications->setGeometry(YRect(leftX, 1,
-                                             fApplications->width(),
-                                             ht - 2));
-            fApplications->show();
-            leftX += fApplications->width();
-        }
-#ifdef CONFIG_WINMENU
-        if (fWinList) {
-            fWinList->setGeometry(YRect(leftX, 1, fWinList->width(), ht - 2));
-            fWinList->show();
-            leftX += fWinList->width();
-        }
-#endif
-        if (fShowDesktop) {
-            fShowDesktop->setGeometry(YRect(leftX, 1, fShowDesktop->width(), ht - 2));
-            fShowDesktop->show();
-            leftX += fShowDesktop->width();
-        }
-        if (leftX > 0) leftX += 4;
-#ifndef NO_CONFIGURE_MENUS
-        if (fObjectBar) {
-            fObjectBar->setGeometry(YRect(leftX, 1, fObjectBar->width(), ht - 2));
-            fObjectBar->show();
-            leftX += fObjectBar->width() + 4;
-        }
-#endif
-
-        if (fWorkspaces && taskBarWorkspacesLeft) {
-            fWorkspaces->setGeometry(YRect(leftX, 1, fWorkspaces->width(), ht - 2));
-            leftX += fWorkspaces->width() + 4;
-            fWorkspaces->show();
-        }
-#ifdef CONFIG_ADDRESSBAR
-        if (fAddressBar && taskBarShowWindows) {
-            fAddressBar->setGeometry(YRect(leftX, 1, rightX - leftX, height() - 2));
-        }
-#endif
-    }
-
-    if (fTray2->visible()) {
-//        int w;
-        int h((int) height() - ((wmLook == lookMetal) ? 0 : 1));
-        int y(((int) height() - h) / 2 + 1);
-//        w = 48;
-        rightX -= fTray2->width();
-	if (taskBarDoubleHeight) {
-            y = 3 * height() / 4 - (h / 2 - 1) / 2;
-        }
-        fTray2->setPosition(rightX, y);
-    }
+        { fTray2, false, 1, true, 1, 1, false },
 #ifdef CONFIG_TRAY
-    if (fTray) {
-        int trayWidth(fTray->getRequiredWidth());
-        int w((rightX - leftX ) / 2);
-        if (trayWidth > w)
-            trayWidth = w;
-        else
-            w = trayWidth;
+        { fTray, false, 0, true, 1, 1, true },
+#endif
+    };
+    const int wcount = sizeof(wlist)/sizeof(wlist[0]);
 
-        rightX-= w;
+    int w = 0;
+    int y[2] = { 0, 0 };
+    int h[2] = { 0, 0 };
+    int left[2] = { 0, 0 };
+    int right[2] = { 0, 0 };
+    int i;
 
-        int h((int) height() - ((wmLook == lookMetal) ? 0 : 1));
-        int y(((int) height() - h) / 2 + 1);
-
-        if (taskBarDoubleHeight) {
-            h = h / 2 - 1;
-            y = 3 * height() / 4 - h / 2;
-        } else if (trayDrawBevel)
-            rightX -= 2;
-
-        fTray->setGeometry(YRect(rightX, y, w, h));
-        fTray->show();
-        rightX -= 2;
+    for (i = 0; wl = wlist + i, i < wcount; i++) {
+        if (!taskBarDoubleHeight)
+            wl->row = 0;
     }
 
-#endif
+    for (i = 0; wl = wlist + i, i < wcount; i++) {
+        if (wl->w == 0)
+            continue;
+        if (wl->w->height() > h[wl->row])
+            h[wl->row] = wl->w->height();
+    }
+
+    {
+        int dx, dy, dw, dh;
+        manager->getScreenGeometry(&dx, &dy, &dw, &dh);
+        w = dw;
+    }
+
+    if (taskBarAtTop) {
+        y[0] = 0;
+        if (fIsHidden)
+            y[0]++;
+        y[1] = h[0] + y[0];
+    } else {
+        y[1] = 1;
+        y[0] = h[1] + y[1];
+    }
+
+    right[0] = w;
+    right[1] = w;
+
+    for (i = 0; wl = wlist + i, i < wcount; i++) {
+        if (wl->w == 0)
+            continue;
+        if (!wl->show && !wl->w->visible())
+            continue;
+
+        int xx = 0;
+        int yy = 0;
+        int ww = wl->w->width();
+        int hh = h[wl->row];
+
+        if (wl->expand) {
+            yy = y[wl->row];
+        } else {
+            hh = wl->w->height();
+            yy = y[wl->row] + (h[wl->row] - wl->w->height()) / 2;
+        }
+
+        if (wl->left) {
+            xx = left[wl->row] + wl->pre;
+
+            left[wl->row] += ww + wl->pre + wl->post;
+        } else {
+            xx = right[wl->row] - ww - wl->pre;
+
+            right[wl->row] -= ww + wl->pre + wl->post;
+        }
+
+        wl->w->setGeometry(YRect(xx, yy, ww, hh));
+        if (wl->show)
+            wl->w->show();
+    }
+
+    /* ----------------------------------------------------------------- */
+
     if (taskBarShowWindows) {
         if (fTasks) {
-            int h = height() - 2;
-
-            if (taskBarDoubleHeight) {
-                h = ht - 2; //  / 2 - 1;
-            } else {
-                h = ht - 2;
-            }
-            int y = height() - 1 - h;
-            fTasks->setGeometry(YRect(leftX, y, rightX - leftX, h));
+            fTasks->setGeometry(YRect(left[0],
+                                      y[0],
+                                      right[0] - left[0],
+                                      h[0]));
             fTasks->show();
             fTasks->relayout();
         }
-    } else {
-#ifdef CONFIG_ADDRESSBAR
-        if (fAddressBar) {
-            if (!taskBarDoubleHeight) {
-                leftX += 2;
-                fAddressBar->setGeometry(
-                    YRect(leftX,
-                          (ht - fAddressBar->height()) / 2,
-                          rightX - leftX - 4,
-                          fAddressBar->height()));
-                if (showAddressBar) {
-                    fAddressBar->show();
-		}
-            }
-        }
-#endif
     }
+#ifdef CONFIG_ADDRESSBAR
+    if (fAddressBar) {
+        int row = taskBarDoubleHeight ? 1 : 0;
+
+        fAddressBar->setGeometry(YRect(left[row],
+                                       y[row] + 2,
+                                       right[row] - left[row],
+                                       h[row] - 4));
+        fAddressBar->raise();
+        if (showAddressBar) {
+            if (taskBarDoubleHeight || !taskBarShowWindows)
+                fAddressBar->show();
+        }
+    }
+#endif
+
+    size_w = w;
+    size_h = h[0] + h[1] + 1;
 }
 
 void TaskBar::relayoutNow() {
-    if (!fNeedRelayout)
-        return ;
+#ifdef CONFIG_TRAY
+    if (taskBar && taskBar->trayPane())
+        taskBar->trayPane()->relayoutNow();
+#endif
+    if (fNeedRelayout) {
 
-    updateLayout();
-    fNeedRelayout = false;
+        updateLocation();
+        fNeedRelayout = false;
+    }
+    if (taskBar->taskPane())
+        taskBar->taskPane()->relayoutNow();
 }
 
 void TaskBar::updateLocation() {
@@ -827,15 +674,41 @@ void TaskBar::updateLocation() {
 
     int x = dx;
     int y = dy;
-    int h = height();
+    int w = 0;
+    int h = 0;
 
-    {
-        if (fIsHidden)
-            y = taskBarAtTop ? dy - h + 1 : int(dy + dh - 1);
+    updateLayout(w, h);
+
+    if (fIsCollapsed) {
+        w = fCollapseButton->width();
+        h = fCollapseButton->height();
+
+        x = dw - w;
+        if (taskBarAtTop)
+            y = 0;
         else
-            y = taskBarAtTop ? dy - 1: int(dy + dh - h + 1);
+            y = dh - h;
+
+        fCollapseButton->show();
+        fCollapseButton->raise();
+        fCollapseButton->setPosition(0, 0);
     }
 
+    if (fIsHidden) {
+        h = 1;
+        y = taskBarAtTop ? dy : dy + dh - 1;
+    } else {
+        y = taskBarAtTop ? dy : dy + dh - h;
+    }
+
+#if 1
+    if (fIsMapped && getFrame())
+        getFrame()->configureClient(x, y, w, h);
+    else
+#endif
+        setGeometry(YRect(x, y, w, h));
+
+#warning "optimize this"
     {
         MwmHints mwm;
 
@@ -850,8 +723,8 @@ void TaskBar::updateLocation() {
             mwm.decorations = 0;
         else
             mwm.decorations = 0;
-                //MWM_DECOR_BORDER /*|
-                //MWM_DECOR_RESIZEH*/;
+        //MWM_DECOR_BORDER /*|
+        //MWM_DECOR_RESIZEH*/;
 
         XChangeProperty(xapp->display(), handle(),
                         _XATOM_MWM_HINTS, _XATOM_MWM_HINTS,
@@ -862,12 +735,6 @@ void TaskBar::updateLocation() {
             getFrame()->updateMwmHints();
     }
     ///!!! fix
-#if 1
-    if (fIsMapped && getFrame())
-        getFrame()->configureClient(x, y, width(), height());
-    else
-#endif
-        setPosition(x, y);
     updateWMHints();
 }
 
@@ -876,7 +743,7 @@ void TaskBar::updateWMHints() {
     manager->getScreenGeometry(&dx, &dy, &dw, &dh);
 
     long wk[4] = { 0, 0, 0, 0 };
-    if (!taskBarAutoHide && getFrame()) {
+    if (!taskBarAutoHide && !fIsCollapsed && getFrame()) {
         if (taskBarAtTop)
             wk[2] = getFrame()->y() + getFrame()->height();
         else
@@ -946,15 +813,20 @@ void TaskBar::paint(Graphics &g, const YRect &/*r*/) {
         g.copyPixbuf(*fGradient, 0, 0, width(), height(), 0, 0);
     else
 #endif
-    if (taskbackPixmap != null)
-        g.fillPixmap(taskbackPixmap, 0, 0, width(), height());
-    else {
-        g.fillRect(0, 1, width(), height() - 1);
-        g.setColor(taskBarBg->brighter());
-        g.drawLine(0, 0, width(), 0);
-        g.setColor(taskBarBg->darker());
-        g.drawLine(0, height() - 1, width(), height() - 1);
-    }
+        if (taskbackPixmap != null)
+            g.fillPixmap(taskbackPixmap, 0, 0, width(), height());
+        else {
+            int y = taskBarAtTop ? 0 : 1;
+            g.fillRect(0, y, width(), height() - 1);
+            if (!taskBarAtTop) {
+                y++;
+                g.setColor(taskBarBg->brighter());
+                g.drawLine(0, 0, width(), 0);
+            } else {
+                g.setColor(taskBarBg->darker());
+                g.drawLine(0, height() - 1, width(), height() - 1);
+            }
+        }
 }
 
 bool TaskBar::handleKey(const XKeyEvent &key) {
@@ -971,15 +843,15 @@ void TaskBar::handleButton(const XButtonEvent &button) {
             windowList->showFocused(button.x_root, button.y_root);
     } else
 #endif
-    if (button.type == ButtonPress) {
-        manager->updateWorkArea();
-        if (button.button == 1) {
-            if (button.state & xapp->AltMask)
-                lower();
-            else if (!(button.state & ControlMask))
-                raise();
+        if (button.type == ButtonPress) {
+            manager->updateWorkArea();
+            if (button.button == 1) {
+                if (button.state & xapp->AltMask)
+                    lower();
+                else if (!(button.state & ControlMask))
+                    raise();
+            }
         }
-    }
     YWindow::handleButton(button);
 }
 
@@ -1013,6 +885,7 @@ void TaskBar::handleDrag(const XButtonEvent &/*down*/, const XMotionEvent &motio
         //setPosition(x(), taskBarAtTop ? -1 : int(manager->height() - height() + 1));
         manager->setWorkAreaMoveWindows(true);
         updateLocation();
+        repaint();
         //manager->updateWorkArea();
         manager->setWorkAreaMoveWindows(false);
     }
@@ -1022,8 +895,8 @@ void TaskBar::handleDrag(const XButtonEvent &/*down*/, const XMotionEvent &motio
 void TaskBar::popupStartMenu() {
     if (fApplications) {
         /*requestFocus();
-        fApplications->requestFocus();
-        fApplications->setFocus();*/
+         fApplications->requestFocus();
+         fApplications->setFocus();*/
         if (fIsHidden == true)
             popOut();
         fApplications->popupMenu();
@@ -1067,8 +940,10 @@ void TaskBar::showBar(bool visible) {
         if (getFrame() == 0)
             manager->mapClient(handle());
         if (getFrame() != 0) {
-	    setWinLayerHint(taskBarAutoHide ? WinLayerAboveDock :
-			    taskBarKeepBelow ? WinLayerBelow : WinLayerDock);
+
+            setWinLayerHint((taskBarAutoHide || fIsCollapsed) ? WinLayerAboveDock :
+                            taskBarKeepBelow ? WinLayerBelow : WinLayerDock);
+
             getFrame()->setState(WinStateAllWorkspaces, WinStateAllWorkspaces);
             getFrame()->activate(true);
             updateLocation();
@@ -1080,6 +955,14 @@ void TaskBar::actionPerformed(YAction *action, unsigned int modifiers) {
     wmapp->actionPerformed(action, modifiers);
 }
 
+void TaskBar::handleCollapseButton() {
+    fIsCollapsed = !fIsCollapsed;
+    fCollapseButton->setText(fIsCollapsed ? "<": ">");
+
+    relayout();
+    showBar(true);
+}
+
 void TaskBar::handlePopDown(YPopupWindow */*popup*/) {
 }
 
@@ -1094,6 +977,4 @@ void TaskBar::detachTray() {
         delete fTray2; fTray2 = 0;
     }
 }
-
-
 #endif
